ZoCaptureAreaController class

Controller to programmatically capture and share widgets wrapped in a ZoCaptureArea.

Constructors

ZoCaptureAreaController()
Creates a new ZoCaptureAreaController.

Properties

captureKey → GlobalKey<State<StatefulWidget>>
The GlobalKey assigned to the repaint boundary of the capture area.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

capture() → Future<Uint8List?>
Captures the wrapped widget as an image and returns its PNG bytes as a Uint8List.
captureAndShare({String fileName = 'widget_shot.png'}) → Future<void>
Captures the wrapped widget as a PNG image and opens the platform share sheet.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited