ZoNavigatorObserver class

A NavigatorObserver that automatically enables or disables screenshot protection based on current routes.

Inheritance

Constructors

ZoNavigatorObserver({required NavigationStyle navigationStyle, List<String> secureNamedRouteList = const [], List<Type> secureClassRouteList = const []})
Creates a ZoNavigatorObserver to monitor navigation changes and manage screenshot protection.

Properties

hashCode → int
The hash code for this object.
no setterinherited
The navigation style used to evaluate routes.
final
The navigator that the observer is observing, if any.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secureClassRouteList ↔ List<Type>
List of widget Types where screenshots should be blocked.
getter/setter pair
secureNamedRouteList ↔ List<String>
List of named route strings where screenshots should be blocked.
getter/setter pair

Methods

didChangeTop(Route topRoute, Route? previousTopRoute) → void
The top most route has changed.
inherited
didPop(Route route, Route? previousRoute) → void
The Navigator popped route.
override
didPush(Route route, Route? previousRoute) → void
The Navigator pushed route.
override
didRemove(Route route, Route? previousRoute) → void
The Navigator removed route.
inherited
didReplace({Route? newRoute, Route? oldRoute}) → void
The Navigator replaced oldRoute with newRoute.
inherited
didStartUserGesture(Route route, Route? previousRoute) → void
The Navigator's routes are being moved by a user gesture.
inherited
didStopUserGesture() → void
User gesture is no longer controlling the Navigator.
inherited
disableScreenshot() → void
Disables screenshot capture on the platform.
enableScreenshot() → void
Enables screenshot capture on the platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processRouteInfo(Route? currentRoute) → void
Processes the currentRoute to enable or disable screenshot capture based on configuration.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited