ZoScreenshotPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ZoScreenshotPlatform
Implementers

Constructors

ZoScreenshotPlatform()
Constructs a ZoScreenshotPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

disableScreenShot() → void
Disables screenshots on the platform.
enableScreenshot() → void
Enables screenshots on the platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startScreenshotListner() → void
Starts listening for platform screenshot notifications.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ ZoScreenshotPlatform
The default instance of ZoScreenshotPlatform to use.
getter/setter pair