backgroundPreviewWidget property

Widget? backgroundPreviewWidget
final

Custom widget to display when the app is in the background or app switcher.

If null, a default privacy lock screen with a lock icon is displayed.

Implementation

final Widget? backgroundPreviewWidget;