widget_screenshot/zo_capture_area library
Provides widget-level screenshot capture and sharing capabilities.
Classes
- ZoCaptureArea
- A widget that wraps a child inside a RepaintBoundary to allow capturing it as an image via controller.
- ZoCaptureAreaController
- Controller to programmatically capture and share widgets wrapped in a ZoCaptureArea.